@@ -40,8 +40,6 @@
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-module.h>
 
-#include <libnautilus-private/nautilus-autorun.h>
-
 /* string enum preferences */
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_DEFAULT_VIEW_WIDGET "default_view_combobox"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_ICON_VIEW_ZOOM_WIDGET "icon_view_zoom_combobox"
@@ -56,18 +54,14 @@
 
 /* bool preferences */
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_FOLDERS_FIRST_WIDGET "sort_folders_first_checkbutton"
-#define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_COMPACT_LAYOUT_WIDGET "compact_layout_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_LABELS_BESIDE_ICONS_WIDGET "labels_beside_icons_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_ALL_COLUMNS_SAME_WIDTH "all_columns_same_width_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_ALWAYS_USE_BROWSER_WIDGET "always_use_browser_checkbutton"
-#define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_ALWAYS_USE_LOCATION_ENTRY_WIDGET "always_use_location_entry_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_TRASH_CONFIRM_WIDGET "trash_confirm_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_TRASH_DELETE_WIDGET "trash_delete_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_OPEN_NEW_WINDOW_WIDGET "new_window_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_SHOW_HIDDEN_WIDGET "hidden_files_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_TREE_VIEW_FOLDERS_WIDGET "treeview_folders_checkbutton"
-#define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_MEDIA_AUTOMOUNT_OPEN "media_automount_open_checkbutton"
-#define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_MEDIA_AUTORUN_NEVER "media_autorun_never_checkbutton"
 
 /* int enums */
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_THUMBNAIL_LIMIT_WIDGET "preview_image_size_combobox"
@@ -91,9 +85,7 @@ static const char * const zoom_values[] = {
 };
 
 static const char * const sort_order_values[] = {
-	"manually",
 	"name",
-	"directory",
 	"size",
 	"type",
 	"mtime",
@@ -162,7 +154,7 @@ static const char * const icon_captions_components[] = {
 	NULL
 };
 
-static void nautilus_file_management_properties_dialog_update_media_sensitivity (GtkBuilder *builder);
+static GtkWidget *preferences_dialog = NULL;
 
 static void
 nautilus_file_management_properties_size_group_create (GtkBuilder *builder,
@@ -233,29 +225,24 @@ nautilus_file_management_properties_dialog_response_cb (GtkDialog *parent,
 		switch (gtk_notebook_get_current_page (GTK_NOTEBOOK (gtk_builder_get_object (builder, "notebook1")))) {
 		default:
 		case 0:
-			section = "gosnautilus-438";
+			section = "nautilus-views";
 			break;
 		case 1:
-			section = "gosnautilus-56";
+			section = "nautilus-behavior";
 			break;
 		case 2:
-			section = "gosnautilus-439";
+			section = "nautilus-display";
 			break;
 		case 3:
-			section = "gosnautilus-490";
+			section = "nautilus-list";
 			break;
 		case 4:
-			section = "gosnautilus-60";
-			break;
-		case 5:
-			section = "gosnautilus-61";
+			section = "nautilus-preview";
 			break;
 		}
-		preferences_show_help (GTK_WINDOW (parent), "user-guide", section);
+		preferences_show_help (GTK_WINDOW (parent), "gnome-help", section);
 	} else if (response_id == GTK_RESPONSE_CLOSE) {
-		g_signal_handlers_disconnect_by_func (nautilus_media_preferences,
-						      nautilus_file_management_properties_dialog_update_media_sensitivity,
-						      builder);
+		gtk_widget_destroy (GTK_WIDGET (parent));
 	}
 }
 
@@ -536,148 +523,6 @@ nautilus_file_management_properties_dialog_setup_list_column_page (GtkBuilder *b
 	gtk_box_pack_start (GTK_BOX (box), chooser, TRUE, TRUE, 0);
 }
 
-static void
-nautilus_file_management_properties_dialog_update_media_sensitivity (GtkBuilder *builder)
-{
-	gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (builder, "media_handling_vbox")),
-				  ! g_settings_get_boolean (nautilus_media_preferences, NAUTILUS_PREFERENCES_MEDIA_AUTORUN_NEVER));
-}
-
-static void 
-other_type_combo_box_changed (GtkComboBox *combo_box, GtkComboBox *action_combo_box)
-{
-	GtkTreeIter iter;
-	GtkTreeModel *model;
-	char *x_content_type;
-
-	x_content_type = NULL;
-
-	if (!gtk_combo_box_get_active_iter (combo_box, &iter)) {
-		goto out;
-	}
-
-	model = gtk_combo_box_get_model (combo_box);
-	if (model == NULL) {
-		goto out;
-	}
-
-	gtk_tree_model_get (model, &iter, 
-			    2, &x_content_type,
-			    -1);
-
-	nautilus_autorun_prepare_combo_box (GTK_WIDGET (action_combo_box),
-					    x_content_type,
-					    TRUE,
-					    TRUE,
-					    TRUE,
-					    NULL, NULL);
-out:
-	g_free (x_content_type);
-}
-
-
-static void
-nautilus_file_management_properties_dialog_setup_media_page (GtkBuilder *builder)
-{
-	unsigned int n;
-	GList *l;
-	GList *content_types;
-	GtkWidget *other_type_combo_box;
-	GtkListStore *other_type_list_store;
-	GtkCellRenderer *renderer;
-	GtkTreeIter iter;
-	const char *s[] = {"media_audio_cdda_combobox",   "x-content/audio-cdda",
-			   "media_video_dvd_combobox",    "x-content/video-dvd",
-			   "media_music_player_combobox", "x-content/audio-player",
-			   "media_dcf_combobox",          "x-content/image-dcf",
-			   "media_software_combobox",     "x-content/software",
-			   NULL};
-
-	for (n = 0; s[n*2] != NULL; n++) {
-		nautilus_autorun_prepare_combo_box (GTK_WIDGET (gtk_builder_get_object (builder, s[n*2])), s[n*2 + 1],
-						    TRUE, TRUE, TRUE, NULL, NULL);
-	}
-
-	other_type_combo_box = GTK_WIDGET (gtk_builder_get_object (builder, "media_other_type_combobox"));
-
-	other_type_list_store = gtk_list_store_new (3, 
-						    GDK_TYPE_PIXBUF, 
-						    G_TYPE_STRING, 
-						    G_TYPE_STRING);
-
-	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (other_type_list_store),
-					      1, GTK_SORT_ASCENDING);
-
-
-	content_types = g_content_types_get_registered ();
-
-	for (l = content_types; l != NULL; l = l->next) {
-		char *content_type = l->data;
-		char *description;
-		GIcon *icon;
-		NautilusIconInfo *icon_info;
-		GdkPixbuf *pixbuf;
-		int icon_size;
-
-		if (!g_str_has_prefix (content_type, "x-content/"))
-			continue;
-		for (n = 0; s[n*2] != NULL; n++) {
-			if (strcmp (content_type, s[n*2 + 1]) == 0) {
-				goto skip;
-			}
-		}
-
-		icon_size = nautilus_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU);
-
-		description = g_content_type_get_description (content_type);
-		gtk_list_store_append (other_type_list_store, &iter);
-		icon = g_content_type_get_icon (content_type);
-		if (icon != NULL) {
-			icon_info = nautilus_icon_info_lookup (icon, icon_size);
-			g_object_unref (icon);
-			pixbuf = nautilus_icon_info_get_pixbuf_nodefault_at_size (icon_info, icon_size);
-			g_object_unref (icon_info);
-		} else {
-			pixbuf = NULL;
-		}
-
-		gtk_list_store_set (other_type_list_store, &iter, 
-				    0, pixbuf, 
-				    1, description, 
-				    2, content_type, 
-				    -1);
-		if (pixbuf != NULL)
-			g_object_unref (pixbuf);
-		g_free (description);
-	skip:
-		;
-	}
-	g_list_foreach (content_types, (GFunc) g_free, NULL);
-	g_list_free (content_types);
-
-	gtk_combo_box_set_model (GTK_COMBO_BOX (other_type_combo_box), GTK_TREE_MODEL (other_type_list_store));
-	
-	renderer = gtk_cell_renderer_pixbuf_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (other_type_combo_box), renderer, FALSE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (other_type_combo_box), renderer,
-					"pixbuf", 0,
-					NULL);
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (other_type_combo_box), renderer, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (other_type_combo_box), renderer,
-					"text", 1,
-					NULL);
-
-	g_signal_connect (G_OBJECT (other_type_combo_box),
-			  "changed",
-			  G_CALLBACK (other_type_combo_box_changed),
-			  gtk_builder_get_object (builder, "media_other_action_combobox"));
-
-	gtk_combo_box_set_active (GTK_COMBO_BOX (other_type_combo_box), 0);
-
-	nautilus_file_management_properties_dialog_update_media_sensitivity (builder);
-}
-
 static void
 bind_builder_bool (GtkBuilder *builder,
 		   GSettings *settings,
@@ -689,35 +534,15 @@ bind_builder_bool (GtkBuilder *builder,
 			 "active", G_SETTINGS_BIND_DEFAULT);
 }
 
-static gboolean
-inverted_get_mapping (GValue             *value,
-		      GVariant           *variant,
-		      gpointer            user_data)
-{
-	g_value_set_boolean (value, !g_variant_get_boolean (variant));
-	return TRUE;
-}
-
-static GVariant *
-inverted_set_mapping (const GValue       *value,
-		      const GVariantType *expected_type,
-		      gpointer            user_data)
-{
-	return g_variant_new_boolean (!g_value_get_boolean (value));
-}
-
 static void
 bind_builder_bool_inverted (GtkBuilder *builder,
 			    GSettings *settings,
 			    const char *widget_name,
 			    const char *prefs)
 {
-	g_settings_bind_with_mapping (settings, prefs,
-				      gtk_builder_get_object (builder, widget_name),
-				      "active", G_SETTINGS_BIND_DEFAULT,
-				      inverted_get_mapping,
-				      inverted_set_mapping,
-				      NULL, NULL);
+	g_settings_bind (settings, prefs,
+			 gtk_builder_get_object (builder, widget_name),
+			 "active", G_SETTINGS_BIND_INVERT_BOOLEAN);
 }
 
 static gboolean
@@ -919,9 +744,6 @@ nautilus_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow
 	create_date_format_menu (builder);
 
 	/* setup preferences */
-	bind_builder_bool (builder, nautilus_icon_view_preferences,
-			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_COMPACT_LAYOUT_WIDGET,
-			   NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_USE_TIGHTER_LAYOUT);
 	bind_builder_bool (builder, nautilus_icon_view_preferences,
 			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_LABELS_BESIDE_ICONS_WIDGET,
 			   NAUTILUS_PREFERENCES_ICON_VIEW_LABELS_BESIDE_ICONS);
@@ -935,12 +757,6 @@ nautilus_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow
 				    NAUTILUS_FILE_MANAGEMENT_PROPERTIES_ALWAYS_USE_BROWSER_WIDGET,
 				    NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER);
 
-	bind_builder_bool (builder, nautilus_media_preferences,
-			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_MEDIA_AUTOMOUNT_OPEN,
-			   NAUTILUS_PREFERENCES_MEDIA_AUTOMOUNT_OPEN);
-	bind_builder_bool (builder, nautilus_media_preferences,
-			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_MEDIA_AUTORUN_NEVER,
-			   NAUTILUS_PREFERENCES_MEDIA_AUTORUN_NEVER);
 	bind_builder_bool (builder, nautilus_preferences,
 			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_TRASH_CONFIRM_WIDGET,
 			   NAUTILUS_PREFERENCES_CONFIRM_TRASH);
@@ -1014,20 +830,16 @@ nautilus_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow
 
 	nautilus_file_management_properties_dialog_setup_icon_caption_page (builder);
 	nautilus_file_management_properties_dialog_setup_list_column_page (builder);
-	nautilus_file_management_properties_dialog_setup_media_page (builder);
-
-	g_signal_connect_swapped (nautilus_media_preferences,
-				  "changed::" NAUTILUS_PREFERENCES_MEDIA_AUTORUN_NEVER,
-				  G_CALLBACK(nautilus_file_management_properties_dialog_update_media_sensitivity),
-				  builder);
 
 	/* UI callbacks */
 	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "file_management_dialog"));
-	g_signal_connect_data (G_OBJECT (dialog), "response",
+	g_signal_connect_data (dialog, "response",
 			       G_CALLBACK (nautilus_file_management_properties_dialog_response_cb),
 			       g_object_ref (builder),
 			       (GClosureNotify)g_object_unref,
 			       0);
+	g_signal_connect (dialog, "delete-event",
+			  G_CALLBACK (gtk_widget_destroy), NULL);
 
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "system-file-manager");
 
@@ -1035,39 +847,26 @@ nautilus_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow
 		gtk_window_set_screen (GTK_WINDOW (dialog), gtk_window_get_screen(window));
 	}
 
+	preferences_dialog = dialog;
+	g_object_add_weak_pointer (G_OBJECT (dialog), (gpointer *) &preferences_dialog);
 	gtk_widget_show (dialog);
 }
 
-static gboolean
-delete_event_callback (GtkWidget       *widget,
-		       GdkEventAny     *event,
-		       gpointer         data)
-{
-	void (*response_callback) (GtkDialog *dialog,
-				   gint response_id);
-
-	response_callback = data;
-
-	response_callback (GTK_DIALOG (widget), GTK_RESPONSE_CLOSE);
-	
-	return TRUE;
-}
-
 void
-nautilus_file_management_properties_dialog_show (GCallback close_callback, GtkWindow *window)
+nautilus_file_management_properties_dialog_show (GtkWindow *window)
 {
 	GtkBuilder *builder;
 
+	if (preferences_dialog != NULL) {
+		gtk_window_present (GTK_WINDOW (preferences_dialog));
+		return;
+	}
+
 	builder = gtk_builder_new ();
 
 	gtk_builder_add_from_file (builder,
 				   UIDIR "/nautilus-file-management-properties.ui",
 				   NULL);
-	
-	g_signal_connect (G_OBJECT (gtk_builder_get_object (builder, "file_management_dialog")),
-			  "response", close_callback, NULL);
-	g_signal_connect (G_OBJECT (gtk_builder_get_object (builder, "file_management_dialog")),
-			  "delete_event", G_CALLBACK (delete_event_callback), close_callback);
 
 	nautilus_file_management_properties_dialog_setup (builder, window);
 
